# Argsense CLI

**argsense** is a command line interface made with Python.

![](.assets/eg01/20220615143658.jpg)

![](.assets/eg01/20220615143730.jpg)

![](.assets/eg01/20220615143751.jpg)

![](.assets/eg01/20220615143817.jpg)

## Usage

> Currently this section is under construction.

> Please check the folder ./examples for your reference.
